==> grommet-2.5.5.tgz: package/components/RadioButtonGroup/radiobuttongroup.stories.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var SimpleRadioButtonGroup =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(SimpleRadioButtonGroup, _Component);

  function SimpleRadioButtonGroup(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (event) {
      return _this.setState({
        value: event.target.value
      });
    });

    _this.state = {
      value: props.value
    };
    return _this;
  }

  var _proto = SimpleRadioButtonGroup.prototype;

  _proto.render = function render() {
    var value = this.state.value;
    return _react.default.createElement(_grommet.Grommet, {
      theme: _themes.grommet
    }, _react.default.createElement(_grommet.Box, {
      align: "center",
      pad: "large"
    }, _react.default.createElement(_grommet.RadioButtonGroup, _extends({
      name: "radio",
      options: [{
        label: 'Choice 1',
        value: 'c1'
      }, {
        label: 'Choice 2',
        value: 'c2'
      }, {
        label: 'Choice 3',
        value: 'c3'
      }],
      value: value,
      onChange: this.onChange
    }, this.props))));
  };

  return SimpleRadioButtonGroup;
}(_react.Component);

(0, _react2.storiesOf)('RadioButtonGroup', module).add('Simple', function () {
  return _react.default.createElement(SimpleRadioButtonGroup, null);
});

==> grommet-2.7.1.tgz: package/components/RadioButtonGroup/radiobuttongroup.stories.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var SimpleRadioButtonGroup =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(SimpleRadioButtonGroup, _Component);

  function SimpleRadioButtonGroup(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "onChange", function (event) {
      return _this.setState({
        value: event.target.value
      });
    });

    _this.state = {
      value: props.value
    };
    return _this;
  }

  var _proto = SimpleRadioButtonGroup.prototype;

  _proto.render = function render() {
    var value = this.state.value;
    return _react.default.createElement(_grommet.Grommet, {
      theme: _themes.grommet
    }, _react.default.createElement(_grommet.Box, {
      align: "center",
      pad: "large"
    }, _react.default.createElement(_grommet.RadioButtonGroup, _extends({
      name: "radio",
      options: [{
        label: 'Choice 1',
        value: 'c1'
      }, {
        label: 'Choice 2',
        value: 'c2'
      }, {
        label: 'Choice 3',
        value: 'c3'
      }],
      value: value,
      onChange: this.onChange
    }, this.props))));
  };

  return SimpleRadioButtonGroup;
}(_react.Component);

(0, _react2.storiesOf)('RadioButtonGroup', module).add('Simple', function () {
  return _react.default.createElement(SimpleRadioButtonGroup, null);
});
